@@ -97,7 +97,9 @@ require_once dirname(__FILE__).'/init.php';
 require_once dirname(__FILE__).'/inc/UUID.php';
 require_once dirname(__FILE__).'/'.$GLOBALS['database_module'];
 include_once dirname(__FILE__).'/defaultFrontendTexts.php';
-include_once dirname(__FILE__).'/../texts/'.$GLOBALS['language_module'];
+if (file_exists(dirname(__FILE__).'/../texts/'.$GLOBALS['language_module'])) {
+    include_once dirname(__FILE__).'/../texts/'.$GLOBALS['language_module'];
+}
 include_once dirname(__FILE__).'/languages.php';
 require_once dirname(__FILE__).'/defaultconfig.php';
 
@@ -239,7 +241,7 @@ if ($GLOBALS['commandline']) {
         $ref = parse_url($_SERVER['HTTP_REFERER']);
         $parts = explode(':', $_SERVER['HTTP_HOST']);
         if ($ref['host'] != $parts[0] && !in_array($ref['host'], $allowed_referrers)) {
-            echo 'Access denied';
+            echo 'Access denied <script type="text/javascript">document.location = document.location</script>';
             exit;
         }
     }
@@ -310,6 +312,7 @@ if (!empty($GLOBALS['require_login'])) {
                 $_REQUEST['login']));
             $msg = $loginresult[1];
         } else {
+            session_regenerate_id();
             $_SESSION['adminloggedin'] = $remoteAddr;
             $_SESSION['logindetails'] = array(
                 'adminname' => $_REQUEST['login'],
@@ -649,7 +652,7 @@ if (!empty($_SESSION['logindetails']['id']) && defined('PHPLISTNEWSROOT') && PHP
     $phpListNewsLastChecked = getConfig('phpListNewsLastChecked-'.$_SESSION['adminlanguage']['iso']);
     if (empty($phpListNewsLastChecked) || ($phpListNewsLastChecked + 86400 < time())) {
         SaveConfig('phpListNewsLastChecked-'.$_SESSION['adminlanguage']['iso'], time(), 0, 1);
-        $newsIndex = fetchUrl(PHPLISTNEWSROOT.'/'.VERSION.'-'.$_SESSION['adminlanguage']['iso'].'-index.txt');
+        $newsIndex = fetchUrlDirect(PHPLISTNEWSROOT.'/'.VERSION.'-'.$_SESSION['adminlanguage']['iso'].'-index.txt');
         SaveConfig('phpListNewsIndex-'.$_SESSION['adminlanguage']['iso'], $newsIndex, 0, 1);
     }
     $newsIndex = getConfig('phpListNewsIndex-'.$_SESSION['adminlanguage']['iso']);
@@ -710,7 +713,11 @@ if (defined('USE_PDF') && USE_PDF && !defined('FPDF_VERSION')) {
 
 if (WARN_ABOUT_PHP_SETTINGS && !$GLOBALS['commandline']) {
     if (strpos(getenv('REQUEST_URI'), $pageroot.'/admin') !== 0) {
-        Warn($GLOBALS['I18N']->get('The pageroot in your config does not match the current locationCheck your config file.'));
+        Warn(s(
+            'The pageroot in your config "%s" does not match the current location "%s". Check your config file.',
+            $pageroot,
+            strstr(getenv('REQUEST_URI'), '/admin', true)
+        ));
     }
 }
 clearstatcache();
