@@ -1,7 +1,4 @@
 <?php
-
-use chdemko\BitArray\BitArray;
-
 /**
  * SegmentPlugin for phplist.
  *
@@ -22,21 +19,17 @@ use chdemko\BitArray\BitArray;
  * @copyright 2014-2017 Duncan Cameron
  * @license   http://www.gnu.org/licenses/gpl.html GNU General Public License, Version 3
  */
+use phpList\plugin\Common\Container;
+use phpList\plugin\Common\ImageTag;
+use phpList\plugin\Common\PageLink;
+use phpList\plugin\Common\PageURL;
+use phpList\plugin\SegmentPlugin\Segment;
 
-/**
- * Plugin class.
- *
- * @category  phplist
- */
 class SegmentPlugin extends phplistPlugin
 {
     const VERSION_FILE = 'version.txt';
     const GUIDANCE = 'https://resources.phplist.com/plugin/segment#add_segment_conditions';
 
-    private $error_level = E_ALL ^ E_NOTICE ^ E_DEPRECATED ^ E_STRICT;
-    private $selectedSubscribers = null;
-    private $dao;
-
     /*
      *  Inherited variables
      */
@@ -46,123 +39,12 @@ class SegmentPlugin extends phplistPlugin
     public $documentationUrl = 'https://resources.phplist.com/plugin/segment';
     public $settings;
 
-    private function filterEmptyFields(array $conditions)
-    {
-        return array_filter(
-            $conditions,
-            function ($c) {
-                return $c['field'] !== '';
-            }
-        );
-    }
-
-    private function filterIncompleteConditions(array $conditions)
-    {
-        return array_filter(
-            $conditions,
-            function ($c) {
-                return $c['field'] !== '' && isset($c['op']);
-            }
-        );
-    }
-
-    private function deleteNotSent($campaign)
-    {
-        $this->dao->deleteNotSent($campaign);
-    }
-
-    private function selectionQueryJoins(array $conditions)
-    {
-        $cf = new SegmentPlugin_ConditionFactory($this->dao);
-        $joins = array();
-
-        foreach ($conditions as $i => $c) {
-            $field = $c['field'];
-
-            try {
-                $condition = $cf->createCondition($field);
-                $joins[] = $condition->joinQuery($c['op'], isset($c['value']) ? $c['value'] : '');
-            } catch (SegmentPlugin_ConditionException $e) {
-                // do nothing
-            }
-        }
-
-        return $joins;
-    }
-
-    private function loadSubscribers($messageId, array $conditions, $combine)
-    {
-        $highest = $this->dao->highestSubscriberId();
-        $subscribers = BitArray::fromInteger($highest + 1);
-        $joins = $this->selectionQueryJoins($conditions);
-
-        if (count($joins) > 0) {
-            foreach ($this->dao->subscribers($messageId, $joins, $combine) as $row) {
-                $subscribers[(int) $row['id']] = 1;
-            }
-        }
-
-        return $subscribers;
-    }
-
-    private function calculateSubscribers($messageId, array $conditions, $combine)
-    {
-        $this->logger->debug(sprintf(
-            "Prior usage %s\nPrior peak usage %s\nPrior peak real usage %s",
-            memory_get_usage(), memory_get_peak_usage(), memory_get_peak_usage(true)
-        ));
-        $joins = $this->selectionQueryJoins($conditions);
-        $count = $this->dao->calculateSubscribers($messageId, $joins, $combine);
-        $this->logger->debug(sprintf(
-            "Post usage %s\nPost peak usage %s\nPost peak real usage %s",
-            memory_get_usage(), memory_get_peak_usage(), memory_get_peak_usage(true)
-        ));
-
-        return $count;
-    }
-
-    private function render($template, $params)
-    {
-        extract($params);
-        ob_start();
-        require $this->coderoot . $template;
-
-        return ob_get_clean();
-    }
-
-    /**
-     * Saves the segment as a message data field.
-     *
-     * @param int   $messageId message id
-     * @param array $segment   segment
-     * @param array $toUnset   optional segment fields to be unset
-     */
-    private function saveMessageSegment($messageId, array $segment, array $toUnset = [])
-    {
-        foreach ($toUnset as $item) {
-            unset($segment[$item]);
-        }
-        setMessageData($messageId, 'segment', $segment);
-    }
-
-    /**
-     * Remove duplicate entries from a multi-dimensional array.
-     *
-     * @param array $input
-     *
-     * @return array
-     */
-    private function array_unique(array $input)
-    {
-        return array_values(
-            array_intersect_key(
-                $input,
-                array_unique(
-                    array_map('serialize', $input)
-                )
-            )
-        );
-    }
+    private $error_level;
+    private $selectedSubscribers = array();
+    private $dao;
+    private $conditionFactory;
+    private $logger;
+    private $segment = null;
 
     /**
      * Constructor.
@@ -172,22 +54,42 @@ class SegmentPlugin extends phplistPlugin
         $this->coderoot = dirname(__FILE__) . '/' . __CLASS__ . '/';
         $this->settings = array(
             'segment_campaign_max' => array(
-              'description' => s('The maximum number of earlier campaigns to select from'),
-              'type' => 'integer',
-              'value' => 10,
-              'allowempty' => 0,
-              'min' => 4,
-              'max' => 25,
-              'category' => 'Segmentation',
+                'description' => s('The maximum number of earlier campaigns to select from'),
+                'type' => 'integer',
+                'value' => 10,
+                'allowempty' => 0,
+                'min' => 4,
+                'max' => 25,
+                'category' => 'Segmentation',
+            ),
+            'segment_subscribers_max' => array(
+                'description' => s('The maximum number of selected subscribers to display'),
+                'type' => 'integer',
+                'value' => 50,
+                'allowempty' => 0,
+                'min' => 5,
+                'max' => 500,
+                'category' => 'Segmentation',
             ),
             'segment_saved_summary' => array(
-              'description' => s('Summary of saved segments'),
-              'type' => 'textarea',
-              'value' => '',
-              'allowempty' => true,
-              'category' => 'Segmentation',
+                'description' => s('Summary of saved segments'),
+                'type' => 'textarea',
+                'value' => '',
+                'allowempty' => true,
+                'category' => 'Segmentation',
+            ),
+            'segment_attribute_max_length' => array(
+                'description' => s('Limit the display length of an attribute name. Enter 0 to always display the full attribute name'),
+                'type' => 'integer',
+                'value' => 0,
+                'allowempty' => true,
+                'min' => 0,
+                'max' => 100,
+                'category' => 'Segmentation',
             ),
         );
+        $this->error_level = E_ALL ^ E_NOTICE ^ E_DEPRECATED ^ E_STRICT;
+
         parent::__construct();
         $this->version = (is_file($f = $this->coderoot . self::VERSION_FILE))
             ? file_get_contents($f)
@@ -204,27 +106,24 @@ class SegmentPlugin extends phplistPlugin
         global $plugins;
 
         return array(
-            'Common plugin version 3.5.6 or greater installed' => (
+            'phpList version 3.3.2 or later' => version_compare(VERSION, '3.3.2') >= 0,
+            'Common plugin version 3.11.0 or greater must be enabled' => (
                 phpListPlugin::isEnabled('CommonPlugin')
-                && version_compare($plugins['CommonPlugin']->version, '3.5.6') >= 0
+                && version_compare($plugins['CommonPlugin']->version, '3.11.0') >= 0
             ),
             'PHP version 5.4.0 or greater' => version_compare(PHP_VERSION, '5.4') > 0,
         );
     }
 
-    /**
-     * Use this method as a hook to create the dao
-     * Need to create autoloader because of the unpredictable order in which plugins are called.
-     */
-    public function sendFormats()
+    public function activate()
     {
-        global $plugins;
+        parent::activate();
 
-        require_once $plugins['CommonPlugin']->coderoot . 'Autoloader.php';
-        $this->dao = new SegmentPlugin_DAO(new CommonPlugin_DB());
-        $this->logger = CommonPlugin_Logger::instance();
-
-        return;
+        $depends = require $this->coderoot . 'depends.php';
+        $container = new Container($depends);
+        $this->dao = $container->get('SegmentPlugin_DAO');
+        $this->conditionFactory = $container->get('ConditionFactory');
+        $this->logger = $container->get('Logger');
     }
 
     /**
@@ -237,170 +136,6 @@ class SegmentPlugin extends phplistPlugin
         return array();
     }
 
-    /**
-     * Build contents of additional tab.
-     *
-     * @param int   $messageId
-     * @param array $messageData
-     *
-     * @return string the html for the tab
-     */
-    public function sendMessageTab($messageId = 0, $messageData = array())
-    {
-        global $pagefooter;
-
-        $er = error_reporting($this->error_level);
-        $segment = isset($messageData['segment']) ? $messageData['segment'] : array();
-        $conditions = (isset($segment['c']))
-            ? array_values($this->filterEmptyFields($segment['c']))
-            : array();
-        $saved = new SegmentPlugin_SavedSegments();
-
-        if (isset($segment['remove'])) {
-            $this->saveMessageSegment($messageId, $segment, ['c', 'combine', 'remove']);
-            $conditions = [];
-        } elseif (isset($segment['save']) && $segment['savename'] != '') {
-            /*
-             *  Save the current set of conditions
-             */
-            $saved->addSegment($segment['savename'], $this->filterIncompleteConditions($conditions));
-            $this->saveMessageSegment($messageId, $segment, ['save']);
-        } elseif (isset($segment['load']) && isset($segment['usesaved']) && is_array($segment['usesaved'])) {
-            /*
-             *  Load saved segments and save the message data
-             */
-            try {
-                foreach ($segment['usesaved'] as $savedId) {
-                    $savedConditions = $saved->segmentById($savedId);
-                    $conditions = array_merge($conditions, $savedConditions);
-                }
-            } catch (Exception $e) {
-                // do nothing
-            }
-            $conditions = $this->array_unique($conditions);
-            $segment['c'] = $conditions;
-            $this->saveMessageSegment($messageId, $segment, ['load', 'usesaved']);
-        }
-        $combine = isset($segment['combine'])
-            ? $segment['combine'] : SegmentPlugin_Operator::ALL;
-
-        $conditions[] = array('field' => '');
-        $selectPrompt = s('Select ...');
-        $params = array();
-        $params['condition'] = array();
-        $params['selectPrompt'] = $selectPrompt;
-        $cf = new SegmentPlugin_ConditionFactory($this->dao);
-
-        foreach ($conditions as $i => $c) {
-            $s = new stdClass();
-            $params['condition'][] = $s;
-
-            // display field selection drop-down list
-            $s->fieldList = CHtml::dropDownList(
-                "segment[c][$i][field]",
-                $c['field'],
-                array('Subscriber Data' => $cf->subscriberFields(), 'Attributes' => $cf->attributeFields()),
-                array('prompt' => $selectPrompt, 'class' => 'autosubmit')
-            );
-
-            // display hidden input to detect when field changes
-            $s->hiddenField = CHtml::hiddenField("segment[c][$i][_field]", $c['field']);
-            $field = $c['field'];
-
-            if ($field == '') {
-                continue;
-            }
-
-            try {
-                $condition = $cf->createCondition($field);
-            } catch (SegmentPlugin_ConditionException $e) {
-                $s->error = sprintf('Unable to display condition: %s', $e->getMessage());
-                continue;
-            }
-            $condition->messageData = $messageData;
-
-            // display operators drop-down list
-            $operators = $condition->operators();
-
-            $op = ($field == $c['_field'] && isset($c['op'])) ? $c['op'] : key($operators);
-            $s->operatorList = CHtml::dropDownList(
-                "segment[c][$i][op]",
-                $op,
-                $operators,
-                array('class' => 'autosubmit')
-            );
-
-            // display value field
-            $value = ($field == $c['_field'] && isset($c['value'])) ? $c['value'] : '';
-            $s->display = $condition->display($op, $value, "segment[c][$i]");
-        }
-
-        // display warning if no lists have been selected
-        if (!(is_array($messageData['targetlist']) && count($messageData['targetlist']) > 0)) {
-            $params['warning'] = s('Please select at least one list on the Lists tab before adding segmentation conditions');
-        }
-
-        // display fields for saved segments only where there are some
-        $savedListData = $saved->selectListData();
-
-        if (count($savedListData) > 0) {
-            $params['savedList'] = CHtml::dropDownList(
-                'segment[usesaved][]',
-                '',
-                $savedListData,
-                array('multiple' => 'multiple', 'style' => 'width: 50%')
-            );
-            $params['loadButton'] = CHtml::submitButton(s('Load segments'), array('name' => 'segment[load]'));
-            $params['settingsButton'] = new CommonPlugin_PageLink(
-                new CommonPlugin_PageURL('configure', array(), 'segmentation'),
-                'Edit saved segments',
-                array('target' => '_blank', 'class' => 'button')
-            );
-        }
-
-        // display calculate button
-        $params['calculateButton'] = CHtml::submitButton(s('Calculate'), array('name' => 'segment[calculate]'));
-
-        // display combine drop-down list
-        $params['combineList'] = CHtml::dropDownList(
-            'segment[combine]',
-            $combine,
-            array(SegmentPlugin_Operator::ONE => s('any'), SegmentPlugin_Operator::ALL => s('all'))
-        );
-
-        // display calculated number of subscribers
-        if (isset($segment['calculate'])) {
-            try {
-                $params['totalSubscribers'] = $this->calculateSubscribers(
-                    $messageId,
-                    $this->filterIncompleteConditions($segment['c']),
-                    $combine
-                );
-            } catch (SegmentPlugin_ValueException $e) {
-                $params['warning'] = s('One of the conditions has an invalid target value');
-            }
-        }
-
-        // display remove all, save button and input field only when there is at least one entered condition
-        if (count($conditions) > 1) {
-            $params['removeButton'] = CHtml::submitButton(s('Remove all'), array('name' => 'segment[remove]'));
-            $params['saveButton'] = CHtml::submitButton(s('Save segment'), array('name' => 'segment[save]'));
-            $params['saveName'] = CHtml::textField('segment[savename]', '', array('size' => 25, 'placeholder' => 'Name of segment'));
-        }
-
-        // display link to Help page
-        $params['help'] = CHtml::tag(
-            'a',
-            array('href' => self::GUIDANCE, 'target' => '_blank'),
-            new \phpList\plugin\Common\ImageTag('info.png', 'Guidance')
-        );
-        $html = $this->render('sendtab.tpl.php', $params);
-        $pagefooter[basename(__FILE__)] = file_get_contents($this->coderoot . 'script.html');
-        error_reporting($er);
-
-        return $html;
-    }
-
     /**
      * The title of the additional tab.
      *
@@ -413,6 +148,164 @@ class SegmentPlugin extends phplistPlugin
         return s('Segment');
     }
 
+    /**
+     * Build contents of additional tab.
+     *
+     * @param int   $messageId
+     * @param array $messageData
+     *
+     * @return string the html for the tab
+     */
+    public function sendMessageTab($messageId = 0, $messageData = array())
+    {
+        global $pagefooter;
+
+        $er = error_reporting($this->error_level);
+
+        $formFields = isset($messageData['segment']) ? $messageData['segment'] : array();
+        $segment = $this->createSegment($messageId, $formFields);
+        $this->processSegmentCommands($segment, $formFields);
+
+        $selectPrompt = s('Select ...');
+        $params = array();
+        $params['condition'] = array();
+        $params['selectPrompt'] = $selectPrompt;
+
+        foreach ($segment->conditions() as $i => $c) {
+            $s = new stdClass();
+            $params['condition'][] = $s;
+            $field = $c['field'];
+
+            try {
+                $type = $this->conditionFactory->createConditionType($field, $messageData);
+            } catch (SegmentPlugin_ConditionException $e) {
+                $s->error = s('Unable to create condition - %s', $e->getMessage());
+                continue;
+            }
+
+            // display field selection drop-down list
+            $s->fieldList = $this->fieldDropDownList($field, $i, $selectPrompt);
+
+            // display hidden input to detect when field changes
+            $s->hiddenField = CHtml::hiddenField("segment[c][$i][_field]", $field);
+
+            // display operators drop-down list
+            $operators = $type->operators();
+            $selected = isset($c['op']) ? $c['op'] : key($operators);
+            $s->operatorList = CHtml::dropDownList(
+                "segment[c][$i][op]",
+                $selected,
+                $operators,
+                array('class' => 'autosubmit')
+            );
+
+            // display value
+            $value = isset($c['value']) ? $c['value'] : '';
+            $s->display = $type->display($selected, $value, "segment[c][$i]");
+        }
+
+        // add empty field
+        $s = new stdClass();
+        $i = count($segment->conditions());
+        $s->fieldList = $this->fieldDropDownList('', $i, $selectPrompt);
+        $s->hiddenField = CHtml::hiddenField("segment[c][$i][_field]", '');
+        $params['condition'][] = $s;
+
+        // display warning if no lists have been selected
+        if (!(is_array($messageData['targetlist']) && count($messageData['targetlist']) > 0)) {
+            $params['warning'] = s('Please select at least one list on the Lists tab before adding segmentation conditions');
+        }
+
+        // display fields for saved segments only where there are some
+        $saved = new SegmentPlugin_SavedSegments();
+        $savedListData = $saved->selectListData();
+
+        if (count($savedListData) > 0) {
+            $params['savedList'] = CHtml::dropDownList(
+                'segment[usesaved][]',
+                '',
+                $savedListData,
+                array('multiple' => 'multiple', 'style' => 'width: 50%')
+            );
+            $params['loadButton'] = CHtml::submitButton(s('Load segments'), array('name' => 'segment[load]'));
+            $params['settingsButton'] = new PageLink(
+                new PageURL('configure', array(), 'segmentation'),
+                'Edit saved segments',
+                array('target' => '_blank', 'class' => 'button')
+            );
+        }
+
+        // display combine drop-down list
+        $params['combineList'] = CHtml::dropDownList(
+            'segment[combine]',
+            $segment->combine(),
+            array(SegmentPlugin_Operator::ONE => s('any'), SegmentPlugin_Operator::ALL => s('all'))
+        );
+
+        // display calculate button
+        $params['calculateButton'] = CHtml::submitButton(s('Calculate'), array('name' => 'segment[calculate]'));
+
+        // display calculated number of subscribers
+        if (isset($formFields['calculate'])) {
+            try {
+                list($params['totalSubscribers'], $params['subscribers']) = $segment->calculateSubscribers(getConfig('segment_subscribers_max'));
+                $params['exportCalculatedButton'] = new PageLink(
+                    new PageURL('export', array('pi' => 'SegmentPlugin', 'id' => $messageId)),
+                    'Export subscribers',
+                    array('class' => 'button dialog')
+                );
+            } catch (SegmentPlugin_ValueException $e) {
+                $params['warning'] = s('Invalid value for segment condition');
+            } catch (SegmentPlugin_ConditionException $e) {
+                $params['warning'] = s('Unable to create condition - %s', $e->getMessage());
+            }
+        }
+
+        // display remove all, save button and input field only when there is at least one entered condition
+        if (count($segment->conditions()) > 0) {
+            $params['removeButton'] = CHtml::submitButton(s('Remove all'), array('name' => 'segment[remove]'));
+            $params['saveButton'] = CHtml::submitButton(s('Save segment'), array('name' => 'segment[save]'));
+            $params['saveName'] = CHtml::textField('segment[savename]', '', array('size' => 25, 'placeholder' => 'Name of segment'));
+        }
+
+        // display link to Help page
+        $params['help'] = CHtml::tag(
+            'a',
+            array('href' => self::GUIDANCE, 'target' => '_blank'),
+            new ImageTag('info.png', 'Guidance')
+        );
+        $html = $this->render('sendtab.tpl.php', $params);
+        $pagefooter[basename(__FILE__)] = file_get_contents($this->coderoot . 'script.html');
+        error_reporting($er);
+
+        return $html;
+    }
+
+    /**
+     * Validate that conditions are valid for the message to be submitted by calculating the number of subscribers.
+     *
+     * @param array $messageData
+     *
+     * @return string empty string for allow, otherwise error text to be displayed
+     */
+    public function allowMessageToBeQueued($messageData = array())
+    {
+        if (!isset($messageData['segment']['c'])) {
+            return '';
+        }
+        $segment = $this->createSegment($messageData['id'], $messageData['segment']);
+
+        try {
+            list($totalSubscribers, $subscribers) = $segment->calculateSubscribers(getConfig('segment_subscribers_max'));
+        } catch (SegmentPlugin_ValueException $e) {
+            return s('Invalid value for segment condition');
+        } catch (SegmentPlugin_ConditionException $e) {
+            return s('Unable to create condition - %s', $e->getMessage());
+        }
+
+        return '';
+    }
+
     /**
      * Use this hook to delete the 'not sent' rows from the usermessage table
      * so that they will be re-evaluated.
@@ -423,7 +316,7 @@ class SegmentPlugin extends phplistPlugin
      */
     public function messageQueued($id)
     {
-        $this->deleteNotSent($id);
+        $this->dao->deleteNotSent($id);
     }
 
     /**
@@ -449,20 +342,21 @@ class SegmentPlugin extends phplistPlugin
     public function campaignStarted($messageData = array())
     {
         $er = error_reporting($this->error_level);
+        $messageId = $messageData['id'];
+        $this->selectedSubscribers[$messageId] = null;
 
         if (isset($messageData['segment']['c'])) {
-            $conditions = $this->filterIncompleteConditions($messageData['segment']['c']);
+            $segment = $this->createSegment($messageId, $messageData['segment']);
 
-            if (count($conditions) > 0) {
-                try {
-                    $this->selectedSubscribers = $this->loadSubscribers(
-                        $messageData['id'],
-                        $conditions,
-                        $messageData['segment']['combine']
-                    );
-                } catch (SegmentPlugin_ValueException $e) {
-                    logEvent("Invalid segment condition, message {$messageData['id']}");
-                }
+            try {
+                list($total, $this->selectedSubscribers[$messageId]) = $segment->loadSubscribers();
+                logEvent(s('Segment plugin selected %d subscribers for campaign %d', $total, $messageId));
+            } catch (SegmentPlugin_ValueException $e) {
+                logEvent(s('Invalid value for segment condition'));
+            } catch (SegmentPlugin_ConditionException $e) {
+                logEvent(s('Unable to create condition - %s', $e->getMessage()));
+            } catch (SegmentPlugin_NoConditionsException $ex) {
+                // do nothing
             }
         }
         error_reporting($er);
@@ -478,9 +372,12 @@ class SegmentPlugin extends phplistPlugin
      */
     public function canSend($messageData, $userData)
     {
-        return ($this->selectedSubscribers === null)
+        $messageId = $messageData['id'];
+        $userId = (int) $userData['id'];
+
+        return ($this->selectedSubscribers[$messageId] === null)
             ? true
-            : (bool) $this->selectedSubscribers[(int) $userData['id']];
+            : (bool) $this->selectedSubscribers[$messageId][$userId];
     }
 
     /**
@@ -494,27 +391,22 @@ class SegmentPlugin extends phplistPlugin
      */
     public function viewMessage($messageId, array $messageData)
     {
-        $er = error_reporting($this->error_level);
-
         if (!isset($messageData['segment'])) {
             return false;
         }
-        $segment = $messageData['segment'];
+        $formFields = $messageData['segment'];
 
-        if (!isset($segment['c'])) {
+        if (!isset($formFields['c'])) {
             return false;
         }
-        $conditions = array_values($this->filterEmptyFields($segment['c']));
+        $segment = $this->createSegment($messageId, $formFields);
+        $conditions = $segment->conditions();
 
         if (count($conditions) == 0) {
             return false;
         }
-        $combine = isset($segment['combine'])
-            ? $segment['combine'] : SegmentPlugin_Operator::ALL;
-
         $params = array();
         $params['condition'] = array();
-        $cf = new SegmentPlugin_ConditionFactory($this->dao);
 
         foreach ($conditions as $i => $c) {
             $s = new stdClass();
@@ -522,33 +414,30 @@ class SegmentPlugin extends phplistPlugin
             $field = $c['field'];
 
             try {
-                $condition = $cf->createCondition($field);
+                $type = $this->conditionFactory->createConditionType($field, $messageData);
             } catch (SegmentPlugin_ConditionException $e) {
-                $s->error = sprintf('Unable to display condition: %s', $e->getMessage());
+                $s->error = sprintf('Unable to create condition - %s', $e->getMessage());
                 continue;
             }
-            $condition->messageData = $messageData;
 
             // display field selection
-            $fields = $cf->subscriberFields() + $cf->attributeFields();
+            $fields = $this->conditionFactory->subscriberFields() + $this->conditionFactory->attributeFields();
             $s->field = $fields[$field];
 
             // display operator
-            $operators = $condition->operators();
-            $op = ($field == $c['_field'] && isset($c['op'])) ? $c['op'] : key($operators);
+            $operators = $type->operators();
+            $op = isset($c['op']) ? $c['op'] : key($operators);
             $s->operator = $operators[$op];
 
             // display value field
-            $value = ($field == $c['_field'] && isset($c['value'])) ? $c['value'] : '';
-            $s->display = $condition->display($op, $value, "segment[c][$i]");
+            $value = isset($c['value']) ? $c['value'] : '';
+            $s->display = $type->display($op, $value, "segment[c][$i]");
         }
 
         // display combine
         $combineOps = array(SegmentPlugin_Operator::ONE => s('any'), SegmentPlugin_Operator::ALL => s('all'));
-        $params['combine'] = $combineOps[$combine];
-
+        $params['combine'] = $combineOps[$segment->combine()];
         $html = $this->render('viewmessage.tpl.php', $params);
-        error_reporting($er);
 
         return array('Segment conditions', $html);
     }
@@ -564,4 +453,76 @@ class SegmentPlugin extends phplistPlugin
     {
         return array('segment');
     }
+
+    private function render($template, $params)
+    {
+        extract($params);
+        ob_start();
+        require $this->coderoot . $template;
+
+        return ob_get_clean();
+    }
+
+    private function fieldDropDownList($field, $seq, $selectPrompt)
+    {
+        return CHtml::dropDownList(
+            "segment[c][$seq][field]",
+            $field,
+            array('Subscriber Data' => $this->conditionFactory->subscriberFields(), 'Attributes' => $this->conditionFactory->attributeFields()),
+            array('prompt' => $selectPrompt, 'class' => 'autosubmit searchable')
+        );
+    }
+
+    /**
+     * Process segment commands that can change the set of conditions.
+     *
+     * @param Segment $segment
+     * @param array   $formFields
+     */
+    private function processSegmentCommands($segment, $formFields)
+    {
+        $saved = new SegmentPlugin_SavedSegments();
+
+        if (isset($formFields['remove'])) {
+            /*
+             *  Remove all conditions
+             */
+            $segment->removeAll();
+        } elseif (isset($formFields['save']) && $formFields['savename'] != '') {
+            /*
+             *  Save the current set of conditions
+             */
+            $saved->addSegment($formFields['savename'], $segment->conditions());
+        } elseif (isset($formFields['load']) && isset($formFields['usesaved']) && is_array($formFields['usesaved'])) {
+            /*
+             *  Load the selected saved segments
+             */
+            try {
+                foreach ($formFields['usesaved'] as $savedId) {
+                    $savedConditions = $saved->segmentById($savedId);
+                    $segment->addConditions($savedConditions);
+                }
+            } catch (Exception $e) {
+                // do nothing
+            }
+        }
+    }
+
+    /**
+     * Create a segment from the message form fields.
+     *
+     * @param int   $messageId
+     * @param array $formFields
+     *
+     * @return Segment
+     */
+    private function createSegment($messageId, $formFields)
+    {
+        return new Segment(
+            $messageId,
+            isset($formFields['c']) ? $formFields['c'] : array(),
+            isset($formFields['combine']) ? $formFields['combine'] : SegmentPlugin_Operator::ALL,
+            $this->conditionFactory
+        );
+    }
 }
