@@ -46,6 +46,8 @@ class SegmentPlugin_Operator
     const NOTCLICKED = 19;
     const BETWEEN = 20;
     const AFTERINTERVAL = 21;
+    const ISINCLUDED = 22;
+    const ANNIVERSARY = 23;
 
     private function __construct()
     {
