@@ -549,6 +549,9 @@ define('LANGUAGE_SWITCH', 1);
 //# the contents are displayed "as-is", so it will not run any PHP code in the file.
 define('ERROR404PAGE', '404.html');
 
+// Add a Reply-To header. Set this to true to show a Reply to field on the Compose tab when creating a campaign.
+define('USE_REPLY_TO', false);
+
 /*
 
 =========================================================================
@@ -561,14 +564,16 @@ Message sending options
 
 */
 
-// you can specify the location of the phpMailer class here
-// if not set, the version included in the distribution will be used
-//# eg for Debian based systems, it may be something like the example below
-//# when you do this, you may need to run some tests, to see if the phpMailer version
-//# you have works ok
-//define ('PHPMAILER_PATH','/usr/share/php/libphp-phpmailer/class.phpmailer.php');
-// or a more recent version of phpMailer will be like this
-//define ('PHPMAILER_PATH','/usr/share/php/libphp-phpmailer/PHPMailerAutoload.php');
+// If you are using PHPMailer 5 then you can use a different version to the phplist distribution by specifying
+// the location of the PHPMailer autoload file
+// if not set, the PHPMailer version included in the distribution will be used
+// eg for Debian based systems, it may be something like the example below
+// when you do this, you may need to run some tests, to see if the phpMailer version you have works ok
+//define ('PHPMAILER_PATH', '/usr/share/php/libphp-phpmailer/PHPMailerAutoload.php');
+//
+// If you are using PHPMailer 6 then you can use a different version by setting the location of the PHPMailer
+// src directory, e.g.
+//define ('PHPMAILER_PATH', '/var/www/PHPMailer-master/src');
 
 // To use a SMTP server please give your server hostname here, leave it blank to use the standard
 // PHP mail() command.
@@ -599,7 +604,7 @@ define('PHPMAILERHOST', '');
 
 //# SMTP debugging
 // Enable debugging output by phpmailer when sending test emails
-// See https://phpmailer.github.io/PHPMailer/classes/PHPMailer.html#property_SMTPDebug
+// See https://phpmailer.github.io/PHPMailer/classes/PHPMailer.PHPMailer.PHPMailer.html#property_SMTPDebug
 // define('PHPMAILER_SMTP_DEBUG', 0);
 
 //# Smtp Timeout
@@ -633,10 +638,9 @@ Advanced Features, HTML editor, RSS, Attachments, Plugins. PDF creation
 
 // Click tracking
 // If you set this to 1, all links in your emails will be converted to links that
-// go via phpList. This will make sure that clicks are tracked. This is experimental and
-// all your findings when using this feature should be reported to mantis
-// for now it's off by default until we think it works correctly
-define('CLICKTRACK', 0);
+// go via phpList. This will make sure that clicks are tracked. Default: 1
+// If you disable a URL conversion, set to 0.
+define('CLICKTRACK', 1);
 
 // Click track, list detail
 // if you enable this, you will get some extra statistics about unique users who have clicked the
@@ -866,4 +870,11 @@ define('FORWARD_ALTERNATIVE_CONTENT', 0);
 // To disable the automatic updater change the value to false. By default the value is true.
 define('ALLOW_UPDATER', true);
 
+// Google mail Feedback loop configuration
+// When feedback loop is configured in Google mail according to https://support.google.com/mail/answer/6254652?hl=en
+// adds constant to email headers
+define('GOOGLE_SENDERID', '');
 
+// For ajax based signup forms (https://discuss.phplist.org/t/solved-ajax-subscribe-api/974) the access-control-allow-origin header has to be set properly.
+// Add the addresses of the websites you want to allow to perform ajax requests to PHPList.
+define('ACCESS_CONTROL_ALLOW_ORIGINS', ['https://example.com','https://example.org']);
\ No newline at end of file
